@@ -47,7 +47,7 @@ then
 EOL
     echo "Press :'Enter' to confirm , 'Esc' to return back"
     echo
-    opt2=$(gum file --height=6 ~/.config/hypr/brain/config/monitor/)
+    opt2=$(gum file --height=6 --padding=2 --header="Monitor" ~/.config/hypr/brain/config/monitor/)
     cp "$opt2" "$HOME/.config/hypr/settings/monitor.conf"
 elif [[ $opt1 == "waybar " ]]
 then
@@ -116,7 +116,7 @@ EOF
 EOF
         echo "Press :'Enter' to confirm , 'Esc' to return back"
         echo
-        opt2=$(gum file --height=3 "$HOME/.config/hypr/brain/config/status_bar/")
+        opt2=$(gum file --padding="2" --header="Blur"  --height=3 "$HOME/.config/hypr/brain/config/status_bar/") ## idea still need to be thought of
         cp  "$opt2" "$HOME/.config/hypr/settings/status_bar.conf"
     fi
     elif [[ $opt1 == "blur" ]]
@@ -132,7 +132,7 @@ EOF
 EOF
         echo "Press :'Enter' to confirm , 'Esc' to return back"
         echo
-        opt2=$(gum file --height=20 "$HOME/.config/hypr/brain/config/blur_system/")
+        opt2=$(gum file --padding=2 --height=20 --header="blur" "$HOME/.config/hypr/brain/config/blur_system/")
         cp "$opt2" "$HOME/.config/hypr/settings/blur_system.conf"
     elif [[ $opt1 == "eye protection" ]]
     then
@@ -147,7 +147,7 @@ EOF
 EOF
         echo "Press :'Enter' to confirm , 'Esc' to return back"
         echo
-        opt2=$(gum file --height=5 ~/.config/hypr/brain/config/eye_protection/)
+        opt2=$(gum file --padding=2 --header="eye protection" --height=5 ~/.config/hypr/brain/config/eye_protection/)
         if [[ "$opt2" ]]
         then
             cp "$opt2" "$HOME/.config/hypr/settings/eye_protection.conf"
@@ -167,7 +167,7 @@ EOF
 EOF
         echo "Press :'Enter' to confirm , 'Esc' to return back"
         echo
-        opt2=$(gum file --height=3 ~/.config/hypr/brain/config/corners/)
+        opt2=$(gum file --padding=2 --header="corners" --height=3 ~/.config/hypr/brain/config/corners/)
         if [[ "$opt2" ]]
         then
             cp "$opt2" "$HOME/.config/hypr/settings/corners.conf"
@@ -185,7 +185,7 @@ __      _(_)_ __   __| | _____      __   __ _  __ _ _ __  ___
 EOF
         echo "Press :'Enter' to confirm , 'Esc' to return back"
         echo
-        opt2=$(gum file --height=7 ~/.config/hypr/brain/config/window_gaps/)
+        opt2=$(gum file --header="window gaps" --padding=2 --height=7 ~/.config/hypr/brain/config/window_gaps/)
         if [[ "$opt2" ]]
         then
             cp "$opt2" "$HOME/.config/hypr/settings/window_gaps.conf"
@@ -301,13 +301,11 @@ EOF
             fi
             if [[ $opt4 == "add photos" ]]
             then
-                echo "Navigate to the photo : "
-                opt5=$(gum file --height=20 "$HOME")
+                opt5=$(gum file --header="Navigate to the photo : " --padding=2 --height=20 "$HOME")
                 cp "$opt5" "$HOME/custom_wallpapers/photos/"
             elif [[ $opt4 == "add animated" ]]
             then
-                echo "Navigate to the video/gif : "
-                opt5=$(gum file --height=20 "$HOME")
+                opt5=$(gum file --padding=2 --header="Navigate to the video/gif : " --height=20 "$HOME")
                 var1=$(basename "$opt5")
                 var2=$(echo "$var1" | cut -d'.' -f2 )
                 var3=$(echo "$var1" | cut -d'.' -f1 )
@@ -447,7 +445,7 @@ EOF
 EOF
         echo "Press :'Enter' to confirm , 'Esc' to return back"
         echo
-        opt2=$(gum file --height=4 ~/.config/hypr/brain/config/animations/)
+        opt2=$(gum file --header="Animations" --padding=2 --height=4 ~/.config/hypr/brain/config/animations/)
         if [[ "$opt2" ]]
         then
             cp "$opt2" "$HOME/.config/hypr/settings/animations.conf"
@@ -478,7 +476,7 @@ EOF
 
             echo "Press :'Enter' to confirm , 'Esc' to return back"
             echo
-            opt2=$(gum file --height=6 ~/.config/hypr/brain/config/shadow/color/)
+            opt2=$(gum file --padding=2 --header="shadow color" --height=6 ~/.config/hypr/brain/config/shadow/color/)
             cp "$opt2" "$HOME/.config/hypr/settings/shadow_color.conf"
         elif [[ $opt2 == "shadow range" ]]
         then
@@ -494,7 +492,7 @@ EOF
 
             echo "Press :'Enter' to confirm , 'Esc' to return back"
             echo
-            opt2=$(gum file --height=6 ~/.config/hypr/brain/config/shadow/range/)
+            opt2=$(gum file --padding=2 --header="shadow range" --height=6 ~/.config/hypr/brain/config/shadow/range/)
             cp "$opt2" "$HOME/.config/hypr/settings/shadow_range.conf"
 
             # shadow color code to be written here
@@ -538,7 +536,7 @@ EOF
 EOF
             echo "Press :'Enter' to confirm , 'Esc' to return back"
             echo
-            opt4=$(gum file --height=12 ~/.config/hypr/brain/config/borders/colors/active/)
+            opt4=$(gum file --padding=2 --header="Active color" --height=12 ~/.config/hypr/brain/config/borders/colors/active/)
             cp "$opt4" "$HOME/.config/hypr/settings/border_color_active.conf"
             elif [[ $opt3 == "Inactive border" ]]
             then
@@ -552,7 +550,7 @@ EOF
 EOF
             echo "Press :'Enter' to confirm , 'Esc' to return back"
             echo
-            opt4=$(gum file --height=12 ~/.config/hypr/brain/config/borders/colors/inactive/)
+            opt4=$(gum file --padding=2 --header="Inactive color" --height=12 ~/.config/hypr/brain/config/borders/colors/inactive/)
             cp "$opt4" "$HOME/.config/hypr/settings/border_color_inactive.conf"
             fi
         elif [[ $opt2 == "border size" ]]
@@ -584,8 +582,9 @@ EOF
 EOF
         echo "Press :'Enter' to confirm , 'Esc' to return back"
         echo
-        opt2=$(gum file --height=3 ~/.config/hypr/brain/config/layouts/)
+        opt2=$(gum file --header="Layouts" --padding=2 --height=3 ~/.config/hypr/brain/config/layouts/)
         cp "$opt2" "$HOME/.config/hypr/settings/layouts.conf"
 fi
 clear
 done
+
